<?php

namespace App\Notifications\Netmails;

use Carbon\Carbon;
use Illuminate\Support\Facades\Log;

use App\Classes\FTN\Message;
use App\Notifications\Netmails;
use App\Models\{Netmail,System};
use App\Traits\{MessagePath,PageTemplate};

class EchoareaNotExist extends Netmails
{
	use MessagePath,PageTemplate;

	private const LOGKEY = 'NNW';

	private Message $mo;

	/**
	 * Send a sysop a message if they attempt to write to an area that doesnt exist.
	 *
	 * @param Message $mo
	 */
	public function __construct(Message $mo)
	{
		parent::__construct();

		$this->mo = $mo;
	}

	/**
	 * Get the mail representation of the notification.
	 *
	 * @param mixed $notifiable
	 * @return Netmail
	 * @throws \Exception
	 */
	public function toNetmail(object $notifiable): Netmail
	{
		$o = $this->setupNetmail($notifiable);
		$ao = $notifiable->routeNotificationFor(static::via);

		Log::info(sprintf('%s:+ Creating ECHOMAIL NOT EXIST netmail to [%s]',self::LOGKEY,$ao->ftn));

		$o->subject = 'Echoarea doesnt exist - '.$this->mo->echoarea;

		// Message
		$msg = $this->page(FALSE,'nothere');

		$msg->addText(
			sprintf("Your echomail with ID [%s] to [%s] here was received here on [%s] and it looks like you sent it on [%s].\r\r",
				$this->mo->msgid,
				$this->mo->user_to,
				Carbon::now()->utc()->toDateTimeString(),
				$this->mo->date->utc()->toDateTimeString(),
			)
		);

		$msg->addText("It appears that the echoarea that this message is for doesnt exist, so the message from your system was rejected.\r\r");
		$msg->addText("Please contact the ZC if you think this is a mistake.\r\r");

		$msg->addText($this->message_path($this->mo));

		$o->msg = $msg->render();
		$o->tagline = 'Don\'t let your trash become someone else\'s treasure. Feed your shredder often.';

		$o->save();

		return $o;
	}
}