<?php

namespace App\Notifications\Netmails;

use Carbon\Carbon;
use Illuminate\Support\Facades\Log;

use App\Classes\FTN\Message;
use App\Notifications\Netmails;
use App\Models\{Netmail,System};
use App\Traits\{MessagePath,PageTemplate};

class EchoareaNotSubscribed extends Netmails
{
	use MessagePath,PageTemplate;

	private const LOGKEY = 'NNW';

	private Message $mo;

	/**
	 * Send a sysop a message if they write to an area that they hadnt previously subscribed to.
	 *
	 * @param Message $mo
	 */
	public function __construct(Message $mo)
	{
		parent::__construct();

		$this->mo = $mo;
	}

	/**
	 * Get the mail representation of the notification.
	 *
	 * @param mixed $notifiable
	 * @return Netmail
	 * @throws \Exception
	 */
	public function toNetmail(object $notifiable): Netmail
	{
		$o = $this->setupNetmail($notifiable);
		$ao = $notifiable->routeNotificationFor(static::via);

		Log::info(sprintf('%s:+ Creating ECHOMAIL NOT SUBSCRIBED netmail to [%s]',self::LOGKEY,$ao->ftn));

		$o->subject = 'Echoarea not subscribed - '.$this->mo->echoarea;

		// Message
		$msg = $this->page(FALSE,'nothere');

		$msg->addText(
			sprintf("Your echomail with ID [%s] to [%s] here was received here on [%s] and it looks like you sent it on [%s].\r\r",
				$this->mo->msgid,
				$this->mo->user_to,
				Carbon::now()->utc()->toDateTimeString(),
				$this->mo->date->utc()->toDateTimeString(),
			)
		);

		$msg->addText(sprintf("It appears that you havent been previously subscribed to this echoarea using the address [%s].\r\r",$ao->ftn));

		$msg->addText("Even though your post was accepted, I'm not configured to export any posts to you when others respond, you might like to log in to the web interface and do that.\r\r");

		$msg->addText($this->message_path($this->mo));

		$o->msg = $msg->render();
		$o->tagline = 'Don\'t let your trash become someone else\'s treasure. Feed your shredder.';

		$o->save();

		return $o;
	}
}